@@ -7,10 +7,12 @@ class HandleFilters:
 
     def filter(self, findings):
         tag_list = self.remote_config["TAG_FILTER"]
+        severity_list = ["critical", "high", "medium", "low"]
         return list(
             filter(
                 lambda finding: finding.active
-                and any(tag in finding.tags for tag in tag_list),
+                and any(tag in finding.tags for tag in tag_list)
+                and (finding.severity.lower() in severity_list),
                 findings,
             )
         )
